==> libpcbsd-0.95.tar.gz: libpcbsd/utils.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by Tim McCormick   *
 *   tim@pcbsd.org   *
 *                                                                         *
 *   Permission is hereby granted, free of charge, to any person obtaining *
 *   a copy of this software and associated documentation files (the       *
 *   "Software"), to deal in the Software without restriction, including   *
 *   without limitation the rights to use, copy, modify, merge, publish,   *
 *   distribute, sublicense, and/or sell copies of the Software, and to    *
 *   permit persons to whom the Software is furnished to do so, subject to *
 *   the following conditions:                                             *
 *                                                                         *
 *   The above copyright notice and this permission notice shall be        *
 *   included in all copies or substantial portions of the Software.       *
 *                                                                         *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,       *
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF    *
 *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. *
 *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR     *
 *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, *
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR *
 *   OTHER DEALINGS IN THE SOFTWARE.                                       *
 ***************************************************************************/

#include <sys/types.h>
#include <sys/sysctl.h>

#include <qstring.h>

#include "pcbsd-utils.h"

QString Utils::sysctl(QString sysctl)
{
   char result[1000];
   size_t len = sizeof(result);
   sysctlbyname(sysctl.toAscii(), result, &len, NULL, 0);
   result[len] = '\0';
   return QString(result);
}

int Utils::sysctlAsInt(QString sysctl)
{
   int result = 0;
   size_t len = sizeof(result);
   sysctlbyname(sysctl.toAscii(), &result, &len, NULL, 0);
   return result;
}

QString Utils::bytesToHumanReadable(float bytes)
{
   QString suffix[] = {"B", "KB", "MB", "GB", "TB"};
   int i = 0;
   while((bytes >= 1000) && (i < 4))
   {
      bytes = bytes / 1024;
      i++;
   }
   QString result = QString::number(bytes, 'f', 0);
   return result += suffix[i];
}

==> libpcbsd-8.0.tar.gz: libpcbsd/utils.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by Tim McCormick   *
 *   tim@pcbsd.org   *
 *                                                                         *
 *   Permission is hereby granted, free of charge, to any person obtaining *
 *   a copy of this software and associated documentation files (the       *
 *   "Software"), to deal in the Software without restriction, including   *
 *   without limitation the rights to use, copy, modify, merge, publish,   *
 *   distribute, sublicense, and/or sell copies of the Software, and to    *
 *   permit persons to whom the Software is furnished to do so, subject to *
 *   the following conditions:                                             *
 *                                                                         *
 *   The above copyright notice and this permission notice shall be        *
 *   included in all copies or substantial portions of the Software.       *
 *                                                                         *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,       *
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF    *
 *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. *
 *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR     *
 *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, *
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR *
 *   OTHER DEALINGS IN THE SOFTWARE.                                       *
 ***************************************************************************/

#include <sys/types.h>
#include <sys/sysctl.h>

#include <qstring.h>

#include "pcbsd-utils.h"

QString Utils::sysctl(QString sysctl)
{
   char result[1000];
   size_t len = sizeof(result);
   sysctlbyname(sysctl.toAscii(), result, &len, NULL, 0);
   result[len] = '\0';
   return QString(result);
}

long long Utils::sysctlAsInt(QString sysctl)
{
   long long result = 0;
   size_t len = sizeof(result);
   sysctlbyname(sysctl.toAscii(), &result, &len, NULL, 0);
   return result;
}

QString Utils::bytesToHumanReadable(long long bytes)
{
   QString suffix[] = {"B", "KB", "MB", "GB", "TB"};
   int i = 0;
   while((bytes >= 1000) && (i < 4))
   {
      bytes = bytes / 1024;
      i++;
   }
   QString result = QString::number(bytes, 'f', 0);
   return result += suffix[i];
}
